==> jc-1.4.0.tar.gz: soot/util/Numberer__24NumbererIterator.h <==
// final class soot.util.Numberer$NumbererIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f2781e341d7516f soot_util_Numberer__24NumbererIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Numberer__24NumbererIterator_H_
#define _JC_soot_util_Numberer__24NumbererIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_util_Numberer__24NumbererIterator$sub_refs	_jc_soot_util_Numberer__24NumbererIterator$sub_refs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs	_jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$refs	_jc_soot_util_Numberer__24NumbererIterator$refs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$nonrefs	_jc_soot_util_Numberer__24NumbererIterator$nonrefs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$object	_jc_soot_util_Numberer__24NumbererIterator$object;

typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vmethods	_jc_soot_util_Numberer__24NumbererIterator$vmethods;
typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vtable	_jc_soot_util_Numberer__24NumbererIterator$vtable;
typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vtype	_jc_soot_util_Numberer__24NumbererIterator$vtype;

// Constructors
extern void _jc_soot_util_Numberer__24NumbererIterator$method$_init$a9bbd9fd826100cb(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *, struct _jc_soot_util_Numberer$object *, struct _jc_soot_util_Numberer$object *);

// Virtual methods
extern jboolean _jc_soot_util_Numberer__24NumbererIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_Numberer__24NumbererIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
extern void _jc_soot_util_Numberer__24NumbererIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
extern void _jc_soot_util_Numberer__24NumbererIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_Numberer__24NumbererIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *);
};

// Vtable
struct _jc_soot_util_Numberer__24NumbererIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer__24NumbererIterator$vmethods	soot_util_Numberer__24NumbererIterator;
};

// Vtype
struct _jc_soot_util_Numberer__24NumbererIterator$vtype {
	_jc_type			type;
	_jc_soot_util_Numberer__24NumbererIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Numberer__24NumbererIterator$sub_refs {
	struct _jc_soot_util_Numberer$object	*numb;
	struct _jc_soot_util_Numberer$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_Numberer__24NumbererIterator$refs {
    _jc_soot_util_Numberer__24NumbererIterator$sub_refs	soot_util_Numberer__24NumbererIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_Numberer__24NumbererIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs	soot_util_Numberer__24NumbererIterator;
};

// Object instance structure
struct _jc_soot_util_Numberer__24NumbererIterator$object {
	_jc_soot_util_Numberer__24NumbererIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Numberer__24NumbererIterator$vtype	*vtype;
	_jc_soot_util_Numberer__24NumbererIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Numberer__24NumbererIterator$vtype _jc_soot_util_Numberer__24NumbererIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Numberer__24NumbererIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Numberer__24NumbererIterator$class_object;

#endif	/* _JC_soot_util_Numberer__24NumbererIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/Numberer__24NumbererIterator.h <==
// final class soot.util.Numberer$NumbererIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f2781e341d7516f soot_util_Numberer__24NumbererIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Numberer__24NumbererIterator_H_
#define _JC_soot_util_Numberer__24NumbererIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_util_Numberer__24NumbererIterator$sub_refs	_jc_soot_util_Numberer__24NumbererIterator$sub_refs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs	_jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$refs	_jc_soot_util_Numberer__24NumbererIterator$refs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$nonrefs	_jc_soot_util_Numberer__24NumbererIterator$nonrefs;
typedef struct _jc_soot_util_Numberer__24NumbererIterator$object	_jc_soot_util_Numberer__24NumbererIterator$object;

typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vmethods	_jc_soot_util_Numberer__24NumbererIterator$vmethods;
typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vtable	_jc_soot_util_Numberer__24NumbererIterator$vtable;
typedef const struct _jc_soot_util_Numberer__24NumbererIterator$vtype	_jc_soot_util_Numberer__24NumbererIterator$vtype;

// Constructors
extern void _jc_soot_util_Numberer__24NumbererIterator$method$_init$a9bbd9fd826100cb(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *, struct _jc_soot_util_Numberer$object *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_Numberer__24NumbererIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_Numberer__24NumbererIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_Numberer__24NumbererIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_Numberer__24NumbererIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_Numberer__24NumbererIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_Numberer__24NumbererIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_Numberer__24NumbererIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_Numberer__24NumbererIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer__24NumbererIterator$vmethods	soot_util_Numberer__24NumbererIterator;
};

// Vtype
struct _jc_soot_util_Numberer__24NumbererIterator$vtype {
	_jc_type			type;
	_jc_soot_util_Numberer__24NumbererIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Numberer__24NumbererIterator$sub_refs {
	struct _jc_soot_util_Numberer$object	*numb;
	struct _jc_soot_util_Numberer$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_Numberer__24NumbererIterator$refs {
    _jc_soot_util_Numberer__24NumbererIterator$sub_refs	soot_util_Numberer__24NumbererIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_Numberer__24NumbererIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer__24NumbererIterator$sub_nonrefs	soot_util_Numberer__24NumbererIterator;
};

// Object instance structure
struct _jc_soot_util_Numberer__24NumbererIterator$object {
	_jc_soot_util_Numberer__24NumbererIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Numberer__24NumbererIterator$vtype	*vtype;
	_jc_soot_util_Numberer__24NumbererIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Numberer__24NumbererIterator$vtype _jc_soot_util_Numberer__24NumbererIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Numberer__24NumbererIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Numberer__24NumbererIterator$class_object;

#endif	/* _JC_soot_util_Numberer__24NumbererIterator_H_ */
